# Optimisers

To use it:

```bash
pip install git+https://github.com/we-taper/roto.git@A_Particular_Commit_Or_Brach_Or_Tag
```

E.g.

```bash
pip install git+https://github.com/we-taper/roto.git@v1.0.0
```
# Implemented:

- RotoSolver, paper [link](https://arxiv.org/abs/1903.12166).

